@@ -21,6 +21,7 @@ import torchmetrics
 from torchmetrics.detection.mean_ap import MeanAveragePrecision
 
 # Standard imports.
+from pathlib import Path
 from typing import List, Union
 import gc
 import matplotlib.pyplot as plt
@@ -586,19 +587,19 @@ def save_imgs(imgs, base_path, base_name):
     return None
 
 
-def instance_seg_process_images(imgs, predictions, config):
+def maskrcnn_process_images(imgs, preds, class_map, config):
     """
     TODO: DOCUMENT.
     """
 
-    preds_cut = apply_score_cut(predictions, config["score_cut"])
+    preds_cut = apply_score_cut(preds, config["score_cut"])
 
     processed_imgs = imgs
     if config["boxes"]:
         processed_imgs = display_boxes(
             processed_imgs,
             preds_cut,
-            coco_class_map,
+            class_map,
             width=config["box_width"],
             fill=config["box_fill"],
         )
@@ -606,7 +607,7 @@ def instance_seg_process_images(imgs, predictions, config):
         processed_imgs = display_masks_rcnn(
             processed_imgs,
             preds_cut,
-            coco_class_map,
+            class_map,
             threshold=config["mask_threshold"],
             alpha=config["mask_alpha"],
         )
@@ -614,7 +615,7 @@ def instance_seg_process_images(imgs, predictions, config):
         processed_imgs = add_labels(
             processed_imgs,
             preds_cut,
-            coco_class_map,
+            class_map,
             text_size=config["label_size"],
             text_width=config["label_width"],
         )
@@ -622,12 +623,13 @@ def instance_seg_process_images(imgs, predictions, config):
     return processed_imgs
 
 
-def instance_seg_process_video(
+def maskrcnn_process_video(
     raw_video_path,
     processed_video_path,
     config,
     device,
     maskrcnn_model,
+    class_map,
     output_shape=(700, 700),
     show_first_frame=True,
     frame_max=1e4,
@@ -646,7 +648,7 @@ def instance_seg_process_video(
     out = cv2.VideoWriter(
         str(processed_video_path),
         cv2.VideoWriter_fourcc("M", "J", "P", "G"),
-        30,
+        fps,
         output_shape,
     )
 
@@ -670,7 +672,7 @@ def instance_seg_process_video(
             imgs = [img]
             preds = get_preds(imgs, maskrcnn_model, device)
 
-            processed_imgs = instance_seg_process_images(imgs, preds, config)
+            processed_imgs = maskrcnn_process_images(imgs, preds, class_map, config)
 
             if frame_count == 0 and show_first_frame:
                 cv_utility.show(processed_imgs)
